# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetListenerV2Result',
    'AwaitableGetListenerV2Result',
    'get_listener_v2',
    'get_listener_v2_output',
]

@pulumi.output_type
class GetListenerV2Result:
    """
    A collection of values returned by getListenerV2.
    """
    def __init__(__self__, admin_state_up=None, allowed_cidrs=None, alpn_protocols=None, client_authentication=None, client_ca_tls_container_ref=None, client_crl_container_ref=None, connection_limit=None, default_pool=None, default_pool_id=None, default_tls_container_ref=None, description=None, hsts_include_subdomains=None, hsts_max_age=None, hsts_preload=None, id=None, insert_headers=None, l7policies=None, listener_id=None, loadbalancer_id=None, loadbalancers=None, name=None, operating_status=None, pools=None, project_id=None, protocol=None, protocol_port=None, provisioning_status=None, region=None, sni_container_refs=None, tags=None, timeout_client_data=None, timeout_member_connect=None, timeout_member_data=None, timeout_tcp_inspect=None, tls_ciphers=None, tls_versions=None):
        if admin_state_up and not isinstance(admin_state_up, bool):
            raise TypeError("Expected argument 'admin_state_up' to be a bool")
        pulumi.set(__self__, "admin_state_up", admin_state_up)
        if allowed_cidrs and not isinstance(allowed_cidrs, list):
            raise TypeError("Expected argument 'allowed_cidrs' to be a list")
        pulumi.set(__self__, "allowed_cidrs", allowed_cidrs)
        if alpn_protocols and not isinstance(alpn_protocols, list):
            raise TypeError("Expected argument 'alpn_protocols' to be a list")
        pulumi.set(__self__, "alpn_protocols", alpn_protocols)
        if client_authentication and not isinstance(client_authentication, str):
            raise TypeError("Expected argument 'client_authentication' to be a str")
        pulumi.set(__self__, "client_authentication", client_authentication)
        if client_ca_tls_container_ref and not isinstance(client_ca_tls_container_ref, str):
            raise TypeError("Expected argument 'client_ca_tls_container_ref' to be a str")
        pulumi.set(__self__, "client_ca_tls_container_ref", client_ca_tls_container_ref)
        if client_crl_container_ref and not isinstance(client_crl_container_ref, str):
            raise TypeError("Expected argument 'client_crl_container_ref' to be a str")
        pulumi.set(__self__, "client_crl_container_ref", client_crl_container_ref)
        if connection_limit and not isinstance(connection_limit, int):
            raise TypeError("Expected argument 'connection_limit' to be a int")
        pulumi.set(__self__, "connection_limit", connection_limit)
        if default_pool and not isinstance(default_pool, str):
            raise TypeError("Expected argument 'default_pool' to be a str")
        pulumi.set(__self__, "default_pool", default_pool)
        if default_pool_id and not isinstance(default_pool_id, str):
            raise TypeError("Expected argument 'default_pool_id' to be a str")
        pulumi.set(__self__, "default_pool_id", default_pool_id)
        if default_tls_container_ref and not isinstance(default_tls_container_ref, str):
            raise TypeError("Expected argument 'default_tls_container_ref' to be a str")
        pulumi.set(__self__, "default_tls_container_ref", default_tls_container_ref)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if hsts_include_subdomains and not isinstance(hsts_include_subdomains, bool):
            raise TypeError("Expected argument 'hsts_include_subdomains' to be a bool")
        pulumi.set(__self__, "hsts_include_subdomains", hsts_include_subdomains)
        if hsts_max_age and not isinstance(hsts_max_age, int):
            raise TypeError("Expected argument 'hsts_max_age' to be a int")
        pulumi.set(__self__, "hsts_max_age", hsts_max_age)
        if hsts_preload and not isinstance(hsts_preload, bool):
            raise TypeError("Expected argument 'hsts_preload' to be a bool")
        pulumi.set(__self__, "hsts_preload", hsts_preload)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if insert_headers and not isinstance(insert_headers, dict):
            raise TypeError("Expected argument 'insert_headers' to be a dict")
        pulumi.set(__self__, "insert_headers", insert_headers)
        if l7policies and not isinstance(l7policies, list):
            raise TypeError("Expected argument 'l7policies' to be a list")
        pulumi.set(__self__, "l7policies", l7policies)
        if listener_id and not isinstance(listener_id, str):
            raise TypeError("Expected argument 'listener_id' to be a str")
        pulumi.set(__self__, "listener_id", listener_id)
        if loadbalancer_id and not isinstance(loadbalancer_id, str):
            raise TypeError("Expected argument 'loadbalancer_id' to be a str")
        pulumi.set(__self__, "loadbalancer_id", loadbalancer_id)
        if loadbalancers and not isinstance(loadbalancers, list):
            raise TypeError("Expected argument 'loadbalancers' to be a list")
        pulumi.set(__self__, "loadbalancers", loadbalancers)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if operating_status and not isinstance(operating_status, str):
            raise TypeError("Expected argument 'operating_status' to be a str")
        pulumi.set(__self__, "operating_status", operating_status)
        if pools and not isinstance(pools, list):
            raise TypeError("Expected argument 'pools' to be a list")
        pulumi.set(__self__, "pools", pools)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if protocol_port and not isinstance(protocol_port, int):
            raise TypeError("Expected argument 'protocol_port' to be a int")
        pulumi.set(__self__, "protocol_port", protocol_port)
        if provisioning_status and not isinstance(provisioning_status, str):
            raise TypeError("Expected argument 'provisioning_status' to be a str")
        pulumi.set(__self__, "provisioning_status", provisioning_status)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if sni_container_refs and not isinstance(sni_container_refs, list):
            raise TypeError("Expected argument 'sni_container_refs' to be a list")
        pulumi.set(__self__, "sni_container_refs", sni_container_refs)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if timeout_client_data and not isinstance(timeout_client_data, int):
            raise TypeError("Expected argument 'timeout_client_data' to be a int")
        pulumi.set(__self__, "timeout_client_data", timeout_client_data)
        if timeout_member_connect and not isinstance(timeout_member_connect, int):
            raise TypeError("Expected argument 'timeout_member_connect' to be a int")
        pulumi.set(__self__, "timeout_member_connect", timeout_member_connect)
        if timeout_member_data and not isinstance(timeout_member_data, int):
            raise TypeError("Expected argument 'timeout_member_data' to be a int")
        pulumi.set(__self__, "timeout_member_data", timeout_member_data)
        if timeout_tcp_inspect and not isinstance(timeout_tcp_inspect, int):
            raise TypeError("Expected argument 'timeout_tcp_inspect' to be a int")
        pulumi.set(__self__, "timeout_tcp_inspect", timeout_tcp_inspect)
        if tls_ciphers and not isinstance(tls_ciphers, str):
            raise TypeError("Expected argument 'tls_ciphers' to be a str")
        pulumi.set(__self__, "tls_ciphers", tls_ciphers)
        if tls_versions and not isinstance(tls_versions, list):
            raise TypeError("Expected argument 'tls_versions' to be a list")
        pulumi.set(__self__, "tls_versions", tls_versions)

    @_builtins.property
    @pulumi.getter(name="adminStateUp")
    def admin_state_up(self) -> _builtins.bool:
        """
        The administrative state of the Listener.
        """
        return pulumi.get(self, "admin_state_up")

    @_builtins.property
    @pulumi.getter(name="allowedCidrs")
    def allowed_cidrs(self) -> Sequence[_builtins.str]:
        """
        A list of IPv4, IPv6 or mix of both CIDRs.
        """
        return pulumi.get(self, "allowed_cidrs")

    @_builtins.property
    @pulumi.getter(name="alpnProtocols")
    def alpn_protocols(self) -> Sequence[_builtins.str]:
        """
        A list of ALPN protocols.
        """
        return pulumi.get(self, "alpn_protocols")

    @_builtins.property
    @pulumi.getter(name="clientAuthentication")
    def client_authentication(self) -> _builtins.str:
        """
        The TLS client authentication mode.
        """
        return pulumi.get(self, "client_authentication")

    @_builtins.property
    @pulumi.getter(name="clientCaTlsContainerRef")
    def client_ca_tls_container_ref(self) -> _builtins.str:
        """
        The ref of the key manager service secret
        containing a PEM format client CA certificate bundle for TERMINATED_HTTPS listeners.
        """
        return pulumi.get(self, "client_ca_tls_container_ref")

    @_builtins.property
    @pulumi.getter(name="clientCrlContainerRef")
    def client_crl_container_ref(self) -> _builtins.str:
        """
        The URI of the key manager service secret
        containing a PEM format CA revocation list file for TERMINATED_HTTPS listeners.
        """
        return pulumi.get(self, "client_crl_container_ref")

    @_builtins.property
    @pulumi.getter(name="connectionLimit")
    def connection_limit(self) -> _builtins.int:
        """
        The maximum number of connections allowed for the Loadbalancer.
        """
        return pulumi.get(self, "connection_limit")

    @_builtins.property
    @pulumi.getter(name="defaultPool")
    def default_pool(self) -> _builtins.str:
        """
        The default pool with which the Listener is associated.
        """
        return pulumi.get(self, "default_pool")

    @_builtins.property
    @pulumi.getter(name="defaultPoolId")
    def default_pool_id(self) -> _builtins.str:
        """
        The UUID of default pool.
        """
        return pulumi.get(self, "default_pool_id")

    @_builtins.property
    @pulumi.getter(name="defaultTlsContainerRef")
    def default_tls_container_ref(self) -> _builtins.str:
        """
        A reference to a Barbican container of TLS secrets.
        """
        return pulumi.get(self, "default_tls_container_ref")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the listener.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="hstsIncludeSubdomains")
    def hsts_include_subdomains(self) -> _builtins.bool:
        """
        Defines whether the includeSubDomains directive
        should be added to the Strict-Transport-Security HTTP response header.
        """
        return pulumi.get(self, "hsts_include_subdomains")

    @_builtins.property
    @pulumi.getter(name="hstsMaxAge")
    def hsts_max_age(self) -> _builtins.int:
        """
        The value of the max_age directive for the
        Strict-Transport-Security HTTP response header.
        """
        return pulumi.get(self, "hsts_max_age")

    @_builtins.property
    @pulumi.getter(name="hstsPreload")
    def hsts_preload(self) -> _builtins.bool:
        """
        Defines whether the preload directive should be added to the
        Strict-Transport-Security HTTP response header.
        """
        return pulumi.get(self, "hsts_preload")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="insertHeaders")
    def insert_headers(self) -> Mapping[str, _builtins.str]:
        """
        A dictionary of optional headers to insert into the request
        before it is sent to the backend member.
        """
        return pulumi.get(self, "insert_headers")

    @_builtins.property
    @pulumi.getter
    def l7policies(self) -> Sequence['outputs.GetListenerV2L7policyResult']:
        """
        L7policies are the L7 policies which are part of this listener.
        """
        return pulumi.get(self, "l7policies")

    @_builtins.property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> _builtins.str:
        return pulumi.get(self, "listener_id")

    @_builtins.property
    @pulumi.getter(name="loadbalancerId")
    def loadbalancer_id(self) -> _builtins.str:
        return pulumi.get(self, "loadbalancer_id")

    @_builtins.property
    @pulumi.getter
    def loadbalancers(self) -> Sequence['outputs.GetListenerV2LoadbalancerResult']:
        """
        A list of load balancer IDs.
        """
        return pulumi.get(self, "loadbalancers")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the listener.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="operatingStatus")
    def operating_status(self) -> _builtins.str:
        """
        The operating status of the resource.
        """
        return pulumi.get(self, "operating_status")

    @_builtins.property
    @pulumi.getter
    def pools(self) -> Sequence['outputs.GetListenerV2PoolResult']:
        """
        Pools are the pools which are part of this listener.
        """
        return pulumi.get(self, "pools")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The owner (project/tenant) ID of the listener.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> _builtins.str:
        """
        The protocol to loadbalance.
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter(name="protocolPort")
    def protocol_port(self) -> _builtins.int:
        """
        The port on which to listen to client traffic that is
        associated with the Loadbalancer.
        """
        return pulumi.get(self, "protocol_port")

    @_builtins.property
    @pulumi.getter(name="provisioningStatus")
    def provisioning_status(self) -> _builtins.str:
        """
        The provisioning status of the Listener.
        """
        return pulumi.get(self, "provisioning_status")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="sniContainerRefs")
    def sni_container_refs(self) -> Sequence[_builtins.str]:
        """
        The list of references to TLS secrets.
        """
        return pulumi.get(self, "sni_container_refs")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags is a list of resource tags.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="timeoutClientData")
    def timeout_client_data(self) -> _builtins.int:
        """
        Frontend client inactivity timeout in milliseconds.
        """
        return pulumi.get(self, "timeout_client_data")

    @_builtins.property
    @pulumi.getter(name="timeoutMemberConnect")
    def timeout_member_connect(self) -> _builtins.int:
        """
        Backend member connection timeout in milliseconds.
        """
        return pulumi.get(self, "timeout_member_connect")

    @_builtins.property
    @pulumi.getter(name="timeoutMemberData")
    def timeout_member_data(self) -> _builtins.int:
        """
        Backend member inactivity timeout in milliseconds.
        """
        return pulumi.get(self, "timeout_member_data")

    @_builtins.property
    @pulumi.getter(name="timeoutTcpInspect")
    def timeout_tcp_inspect(self) -> _builtins.int:
        """
        Time, in milliseconds, to wait for additional TCP
        packets for content inspection.
        """
        return pulumi.get(self, "timeout_tcp_inspect")

    @_builtins.property
    @pulumi.getter(name="tlsCiphers")
    def tls_ciphers(self) -> _builtins.str:
        """
        List of ciphers in OpenSSL format (colon-separated).
        """
        return pulumi.get(self, "tls_ciphers")

    @_builtins.property
    @pulumi.getter(name="tlsVersions")
    def tls_versions(self) -> Sequence[_builtins.str]:
        """
        A list of TLS protocol versions.
        """
        return pulumi.get(self, "tls_versions")


class AwaitableGetListenerV2Result(GetListenerV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetListenerV2Result(
            admin_state_up=self.admin_state_up,
            allowed_cidrs=self.allowed_cidrs,
            alpn_protocols=self.alpn_protocols,
            client_authentication=self.client_authentication,
            client_ca_tls_container_ref=self.client_ca_tls_container_ref,
            client_crl_container_ref=self.client_crl_container_ref,
            connection_limit=self.connection_limit,
            default_pool=self.default_pool,
            default_pool_id=self.default_pool_id,
            default_tls_container_ref=self.default_tls_container_ref,
            description=self.description,
            hsts_include_subdomains=self.hsts_include_subdomains,
            hsts_max_age=self.hsts_max_age,
            hsts_preload=self.hsts_preload,
            id=self.id,
            insert_headers=self.insert_headers,
            l7policies=self.l7policies,
            listener_id=self.listener_id,
            loadbalancer_id=self.loadbalancer_id,
            loadbalancers=self.loadbalancers,
            name=self.name,
            operating_status=self.operating_status,
            pools=self.pools,
            project_id=self.project_id,
            protocol=self.protocol,
            protocol_port=self.protocol_port,
            provisioning_status=self.provisioning_status,
            region=self.region,
            sni_container_refs=self.sni_container_refs,
            tags=self.tags,
            timeout_client_data=self.timeout_client_data,
            timeout_member_connect=self.timeout_member_connect,
            timeout_member_data=self.timeout_member_data,
            timeout_tcp_inspect=self.timeout_tcp_inspect,
            tls_ciphers=self.tls_ciphers,
            tls_versions=self.tls_versions)


def get_listener_v2(listener_id: Optional[_builtins.str] = None,
                    loadbalancer_id: Optional[_builtins.str] = None,
                    name: Optional[_builtins.str] = None,
                    protocol: Optional[_builtins.str] = None,
                    protocol_port: Optional[_builtins.int] = None,
                    region: Optional[_builtins.str] = None,
                    tags: Optional[Sequence[_builtins.str]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetListenerV2Result:
    """
    Use this data source to get the ID of an OpenStack Load Balancer listener.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_openstack as openstack

    listener1 = openstack.loadbalancer.get_listener_v2(name="listener_1")
    ```


    :param _builtins.str listener_id: The ID of the listener. Exactly one of `name`,
           `listener_id` is required to be set.
    :param _builtins.str loadbalancer_id: The ID of the load balancer associated with
           the requested listener.
    :param _builtins.str name: The name of the listener. Exactly one of `name`,
           `listener_id` is required to be set.
    :param _builtins.str protocol: The protocol of the requested listener.
    :param _builtins.int protocol_port: The port on which the requested listener accepts client traffic.
    :param _builtins.str region: The region in which to obtain the V2 Load Balancer client.
           If omitted, the `region` argument of the provider is used.
    :param Sequence[_builtins.str] tags: A set of tags applied to the loadbalancer's listener.
           The loadbalancer' listener will be returned if it has all of the specified tags.
    """
    __args__ = dict()
    __args__['listenerId'] = listener_id
    __args__['loadbalancerId'] = loadbalancer_id
    __args__['name'] = name
    __args__['protocol'] = protocol
    __args__['protocolPort'] = protocol_port
    __args__['region'] = region
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('openstack:loadbalancer/getListenerV2:getListenerV2', __args__, opts=opts, typ=GetListenerV2Result).value

    return AwaitableGetListenerV2Result(
        admin_state_up=pulumi.get(__ret__, 'admin_state_up'),
        allowed_cidrs=pulumi.get(__ret__, 'allowed_cidrs'),
        alpn_protocols=pulumi.get(__ret__, 'alpn_protocols'),
        client_authentication=pulumi.get(__ret__, 'client_authentication'),
        client_ca_tls_container_ref=pulumi.get(__ret__, 'client_ca_tls_container_ref'),
        client_crl_container_ref=pulumi.get(__ret__, 'client_crl_container_ref'),
        connection_limit=pulumi.get(__ret__, 'connection_limit'),
        default_pool=pulumi.get(__ret__, 'default_pool'),
        default_pool_id=pulumi.get(__ret__, 'default_pool_id'),
        default_tls_container_ref=pulumi.get(__ret__, 'default_tls_container_ref'),
        description=pulumi.get(__ret__, 'description'),
        hsts_include_subdomains=pulumi.get(__ret__, 'hsts_include_subdomains'),
        hsts_max_age=pulumi.get(__ret__, 'hsts_max_age'),
        hsts_preload=pulumi.get(__ret__, 'hsts_preload'),
        id=pulumi.get(__ret__, 'id'),
        insert_headers=pulumi.get(__ret__, 'insert_headers'),
        l7policies=pulumi.get(__ret__, 'l7policies'),
        listener_id=pulumi.get(__ret__, 'listener_id'),
        loadbalancer_id=pulumi.get(__ret__, 'loadbalancer_id'),
        loadbalancers=pulumi.get(__ret__, 'loadbalancers'),
        name=pulumi.get(__ret__, 'name'),
        operating_status=pulumi.get(__ret__, 'operating_status'),
        pools=pulumi.get(__ret__, 'pools'),
        project_id=pulumi.get(__ret__, 'project_id'),
        protocol=pulumi.get(__ret__, 'protocol'),
        protocol_port=pulumi.get(__ret__, 'protocol_port'),
        provisioning_status=pulumi.get(__ret__, 'provisioning_status'),
        region=pulumi.get(__ret__, 'region'),
        sni_container_refs=pulumi.get(__ret__, 'sni_container_refs'),
        tags=pulumi.get(__ret__, 'tags'),
        timeout_client_data=pulumi.get(__ret__, 'timeout_client_data'),
        timeout_member_connect=pulumi.get(__ret__, 'timeout_member_connect'),
        timeout_member_data=pulumi.get(__ret__, 'timeout_member_data'),
        timeout_tcp_inspect=pulumi.get(__ret__, 'timeout_tcp_inspect'),
        tls_ciphers=pulumi.get(__ret__, 'tls_ciphers'),
        tls_versions=pulumi.get(__ret__, 'tls_versions'))
def get_listener_v2_output(listener_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           loadbalancer_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           protocol: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           protocol_port: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                           region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetListenerV2Result]:
    """
    Use this data source to get the ID of an OpenStack Load Balancer listener.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_openstack as openstack

    listener1 = openstack.loadbalancer.get_listener_v2(name="listener_1")
    ```


    :param _builtins.str listener_id: The ID of the listener. Exactly one of `name`,
           `listener_id` is required to be set.
    :param _builtins.str loadbalancer_id: The ID of the load balancer associated with
           the requested listener.
    :param _builtins.str name: The name of the listener. Exactly one of `name`,
           `listener_id` is required to be set.
    :param _builtins.str protocol: The protocol of the requested listener.
    :param _builtins.int protocol_port: The port on which the requested listener accepts client traffic.
    :param _builtins.str region: The region in which to obtain the V2 Load Balancer client.
           If omitted, the `region` argument of the provider is used.
    :param Sequence[_builtins.str] tags: A set of tags applied to the loadbalancer's listener.
           The loadbalancer' listener will be returned if it has all of the specified tags.
    """
    __args__ = dict()
    __args__['listenerId'] = listener_id
    __args__['loadbalancerId'] = loadbalancer_id
    __args__['name'] = name
    __args__['protocol'] = protocol
    __args__['protocolPort'] = protocol_port
    __args__['region'] = region
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('openstack:loadbalancer/getListenerV2:getListenerV2', __args__, opts=opts, typ=GetListenerV2Result)
    return __ret__.apply(lambda __response__: GetListenerV2Result(
        admin_state_up=pulumi.get(__response__, 'admin_state_up'),
        allowed_cidrs=pulumi.get(__response__, 'allowed_cidrs'),
        alpn_protocols=pulumi.get(__response__, 'alpn_protocols'),
        client_authentication=pulumi.get(__response__, 'client_authentication'),
        client_ca_tls_container_ref=pulumi.get(__response__, 'client_ca_tls_container_ref'),
        client_crl_container_ref=pulumi.get(__response__, 'client_crl_container_ref'),
        connection_limit=pulumi.get(__response__, 'connection_limit'),
        default_pool=pulumi.get(__response__, 'default_pool'),
        default_pool_id=pulumi.get(__response__, 'default_pool_id'),
        default_tls_container_ref=pulumi.get(__response__, 'default_tls_container_ref'),
        description=pulumi.get(__response__, 'description'),
        hsts_include_subdomains=pulumi.get(__response__, 'hsts_include_subdomains'),
        hsts_max_age=pulumi.get(__response__, 'hsts_max_age'),
        hsts_preload=pulumi.get(__response__, 'hsts_preload'),
        id=pulumi.get(__response__, 'id'),
        insert_headers=pulumi.get(__response__, 'insert_headers'),
        l7policies=pulumi.get(__response__, 'l7policies'),
        listener_id=pulumi.get(__response__, 'listener_id'),
        loadbalancer_id=pulumi.get(__response__, 'loadbalancer_id'),
        loadbalancers=pulumi.get(__response__, 'loadbalancers'),
        name=pulumi.get(__response__, 'name'),
        operating_status=pulumi.get(__response__, 'operating_status'),
        pools=pulumi.get(__response__, 'pools'),
        project_id=pulumi.get(__response__, 'project_id'),
        protocol=pulumi.get(__response__, 'protocol'),
        protocol_port=pulumi.get(__response__, 'protocol_port'),
        provisioning_status=pulumi.get(__response__, 'provisioning_status'),
        region=pulumi.get(__response__, 'region'),
        sni_container_refs=pulumi.get(__response__, 'sni_container_refs'),
        tags=pulumi.get(__response__, 'tags'),
        timeout_client_data=pulumi.get(__response__, 'timeout_client_data'),
        timeout_member_connect=pulumi.get(__response__, 'timeout_member_connect'),
        timeout_member_data=pulumi.get(__response__, 'timeout_member_data'),
        timeout_tcp_inspect=pulumi.get(__response__, 'timeout_tcp_inspect'),
        tls_ciphers=pulumi.get(__response__, 'tls_ciphers'),
        tls_versions=pulumi.get(__response__, 'tls_versions')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RuleV2Args', 'RuleV2']

@pulumi.input_type
class RuleV2Args:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_port: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 shared: Optional[pulumi.Input[_builtins.bool]] = None,
                 source_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 source_port: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RuleV2 resource.

        :param pulumi.Input[_builtins.str] action: Action to be taken (must be "allow", "deny" or "reject")
               when the firewall rule matches. Changing this updates the `action` of an
               existing firewall rule. Default is `deny`.
        :param pulumi.Input[_builtins.str] description: A description for the firewall rule. Changing this
               updates the `description` of an existing firewall rule.
        :param pulumi.Input[_builtins.str] destination_ip_address: The destination IP address on which the
               firewall rule operates. Changing this updates the `destination_ip_address`
               of an existing firewall rule.
        :param pulumi.Input[_builtins.str] destination_port: The destination port on which the firewall
               rule operates. Changing this updates the `destination_port` of an existing
               firewall rule. Require not `any` or empty protocol.
        :param pulumi.Input[_builtins.bool] enabled: Enabled status for the firewall rule (must be "true"
               or "false" if provided - defaults to "true"). Changing this updates the
               `enabled` status of an existing firewall rule.
        :param pulumi.Input[_builtins.int] ip_version: IP version, either 4 or 6. Changing this
               updates the `ip_version` of an existing firewall rule. Default is `4`.
        :param pulumi.Input[_builtins.str] name: A unique name for the firewall rule. Changing this
               updates the `name` of an existing firewall rule.
        :param pulumi.Input[_builtins.str] project_id: This argument conflicts and is interchangeable
               with `tenant_id`. The owner of the firewall rule. Required if admin wants
               to create a firewall rule for another project. Changing this creates a new
               firewall rule.
        :param pulumi.Input[_builtins.str] protocol: (Optional; Required if `source_port` or `destination_port` is not
               empty) The protocol type on which the firewall rule operates.
               Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
               `protocol` of an existing firewall rule. Default is `any`.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the v2 networking client.
               A networking client is needed to create a firewall rule. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               firewall rule.
        :param pulumi.Input[_builtins.bool] shared: Sharing status of the firewall rule (must be "true"
               or "false" if provided). If this is "true" the policy is visible to, and
               can be used in, firewalls in other tenants. Changing this updates the
               `shared` status of an existing firewall policy. On
        :param pulumi.Input[_builtins.str] source_ip_address: The source IP address on which the firewall
               rule operates. Changing this updates the `source_ip_address` of an existing
               firewall rule.
        :param pulumi.Input[_builtins.str] source_port: The source port on which the firewall
               rule operates. Changing this updates the `source_port` of an existing
               firewall rule. Require not `any` or empty protocol.
        :param pulumi.Input[_builtins.str] tenant_id: This argument conflicts and is interchangeable
               with `project_id`. The owner of the firewall rule. Required if admin wants
               to create a firewall rule for another tenant. Changing this creates a new
               firewall rule.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_ip_address is not None:
            pulumi.set(__self__, "destination_ip_address", destination_ip_address)
        if destination_port is not None:
            pulumi.set(__self__, "destination_port", destination_port)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if shared is not None:
            pulumi.set(__self__, "shared", shared)
        if source_ip_address is not None:
            pulumi.set(__self__, "source_ip_address", source_ip_address)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Action to be taken (must be "allow", "deny" or "reject")
        when the firewall rule matches. Changing this updates the `action` of an
        existing firewall rule. Default is `deny`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description for the firewall rule. Changing this
        updates the `description` of an existing firewall rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="destinationIpAddress")
    def destination_ip_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The destination IP address on which the
        firewall rule operates. Changing this updates the `destination_ip_address`
        of an existing firewall rule.
        """
        return pulumi.get(self, "destination_ip_address")

    @destination_ip_address.setter
    def destination_ip_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "destination_ip_address", value)

    @_builtins.property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The destination port on which the firewall
        rule operates. Changing this updates the `destination_port` of an existing
        firewall rule. Require not `any` or empty protocol.
        """
        return pulumi.get(self, "destination_port")

    @destination_port.setter
    def destination_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "destination_port", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enabled status for the firewall rule (must be "true"
        or "false" if provided - defaults to "true"). Changing this updates the
        `enabled` status of an existing firewall rule.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        IP version, either 4 or 6. Changing this
        updates the `ip_version` of an existing firewall rule. Default is `4`.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ip_version", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A unique name for the firewall rule. Changing this
        updates the `name` of an existing firewall rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This argument conflicts and is interchangeable
        with `tenant_id`. The owner of the firewall rule. Required if admin wants
        to create a firewall rule for another project. Changing this creates a new
        firewall rule.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional; Required if `source_port` or `destination_port` is not
        empty) The protocol type on which the firewall rule operates.
        Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
        `protocol` of an existing firewall rule. Default is `any`.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the v2 networking client.
        A networking client is needed to create a firewall rule. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        firewall rule.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def shared(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Sharing status of the firewall rule (must be "true"
        or "false" if provided). If this is "true" the policy is visible to, and
        can be used in, firewalls in other tenants. Changing this updates the
        `shared` status of an existing firewall policy. On
        """
        return pulumi.get(self, "shared")

    @shared.setter
    def shared(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "shared", value)

    @_builtins.property
    @pulumi.getter(name="sourceIpAddress")
    def source_ip_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The source IP address on which the firewall
        rule operates. Changing this updates the `source_ip_address` of an existing
        firewall rule.
        """
        return pulumi.get(self, "source_ip_address")

    @source_ip_address.setter
    def source_ip_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source_ip_address", value)

    @_builtins.property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The source port on which the firewall
        rule operates. Changing this updates the `source_port` of an existing
        firewall rule. Require not `any` or empty protocol.
        """
        return pulumi.get(self, "source_port")

    @source_port.setter
    def source_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source_port", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This argument conflicts and is interchangeable
        with `project_id`. The owner of the firewall rule. Required if admin wants
        to create a firewall rule for another tenant. Changing this creates a new
        firewall rule.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class _RuleV2State:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_port: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 shared: Optional[pulumi.Input[_builtins.bool]] = None,
                 source_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 source_port: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RuleV2 resources.

        :param pulumi.Input[_builtins.str] action: Action to be taken (must be "allow", "deny" or "reject")
               when the firewall rule matches. Changing this updates the `action` of an
               existing firewall rule. Default is `deny`.
        :param pulumi.Input[_builtins.str] description: A description for the firewall rule. Changing this
               updates the `description` of an existing firewall rule.
        :param pulumi.Input[_builtins.str] destination_ip_address: The destination IP address on which the
               firewall rule operates. Changing this updates the `destination_ip_address`
               of an existing firewall rule.
        :param pulumi.Input[_builtins.str] destination_port: The destination port on which the firewall
               rule operates. Changing this updates the `destination_port` of an existing
               firewall rule. Require not `any` or empty protocol.
        :param pulumi.Input[_builtins.bool] enabled: Enabled status for the firewall rule (must be "true"
               or "false" if provided - defaults to "true"). Changing this updates the
               `enabled` status of an existing firewall rule.
        :param pulumi.Input[_builtins.int] ip_version: IP version, either 4 or 6. Changing this
               updates the `ip_version` of an existing firewall rule. Default is `4`.
        :param pulumi.Input[_builtins.str] name: A unique name for the firewall rule. Changing this
               updates the `name` of an existing firewall rule.
        :param pulumi.Input[_builtins.str] project_id: This argument conflicts and is interchangeable
               with `tenant_id`. The owner of the firewall rule. Required if admin wants
               to create a firewall rule for another project. Changing this creates a new
               firewall rule.
        :param pulumi.Input[_builtins.str] protocol: (Optional; Required if `source_port` or `destination_port` is not
               empty) The protocol type on which the firewall rule operates.
               Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
               `protocol` of an existing firewall rule. Default is `any`.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the v2 networking client.
               A networking client is needed to create a firewall rule. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               firewall rule.
        :param pulumi.Input[_builtins.bool] shared: Sharing status of the firewall rule (must be "true"
               or "false" if provided). If this is "true" the policy is visible to, and
               can be used in, firewalls in other tenants. Changing this updates the
               `shared` status of an existing firewall policy. On
        :param pulumi.Input[_builtins.str] source_ip_address: The source IP address on which the firewall
               rule operates. Changing this updates the `source_ip_address` of an existing
               firewall rule.
        :param pulumi.Input[_builtins.str] source_port: The source port on which the firewall
               rule operates. Changing this updates the `source_port` of an existing
               firewall rule. Require not `any` or empty protocol.
        :param pulumi.Input[_builtins.str] tenant_id: This argument conflicts and is interchangeable
               with `project_id`. The owner of the firewall rule. Required if admin wants
               to create a firewall rule for another tenant. Changing this creates a new
               firewall rule.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_ip_address is not None:
            pulumi.set(__self__, "destination_ip_address", destination_ip_address)
        if destination_port is not None:
            pulumi.set(__self__, "destination_port", destination_port)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if ip_version is not None:
            pulumi.set(__self__, "ip_version", ip_version)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if shared is not None:
            pulumi.set(__self__, "shared", shared)
        if source_ip_address is not None:
            pulumi.set(__self__, "source_ip_address", source_ip_address)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Action to be taken (must be "allow", "deny" or "reject")
        when the firewall rule matches. Changing this updates the `action` of an
        existing firewall rule. Default is `deny`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description for the firewall rule. Changing this
        updates the `description` of an existing firewall rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="destinationIpAddress")
    def destination_ip_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The destination IP address on which the
        firewall rule operates. Changing this updates the `destination_ip_address`
        of an existing firewall rule.
        """
        return pulumi.get(self, "destination_ip_address")

    @destination_ip_address.setter
    def destination_ip_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "destination_ip_address", value)

    @_builtins.property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The destination port on which the firewall
        rule operates. Changing this updates the `destination_port` of an existing
        firewall rule. Require not `any` or empty protocol.
        """
        return pulumi.get(self, "destination_port")

    @destination_port.setter
    def destination_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "destination_port", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enabled status for the firewall rule (must be "true"
        or "false" if provided - defaults to "true"). Changing this updates the
        `enabled` status of an existing firewall rule.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        IP version, either 4 or 6. Changing this
        updates the `ip_version` of an existing firewall rule. Default is `4`.
        """
        return pulumi.get(self, "ip_version")

    @ip_version.setter
    def ip_version(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ip_version", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A unique name for the firewall rule. Changing this
        updates the `name` of an existing firewall rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This argument conflicts and is interchangeable
        with `tenant_id`. The owner of the firewall rule. Required if admin wants
        to create a firewall rule for another project. Changing this creates a new
        firewall rule.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional; Required if `source_port` or `destination_port` is not
        empty) The protocol type on which the firewall rule operates.
        Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
        `protocol` of an existing firewall rule. Default is `any`.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the v2 networking client.
        A networking client is needed to create a firewall rule. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        firewall rule.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def shared(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Sharing status of the firewall rule (must be "true"
        or "false" if provided). If this is "true" the policy is visible to, and
        can be used in, firewalls in other tenants. Changing this updates the
        `shared` status of an existing firewall policy. On
        """
        return pulumi.get(self, "shared")

    @shared.setter
    def shared(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "shared", value)

    @_builtins.property
    @pulumi.getter(name="sourceIpAddress")
    def source_ip_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The source IP address on which the firewall
        rule operates. Changing this updates the `source_ip_address` of an existing
        firewall rule.
        """
        return pulumi.get(self, "source_ip_address")

    @source_ip_address.setter
    def source_ip_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source_ip_address", value)

    @_builtins.property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The source port on which the firewall
        rule operates. Changing this updates the `source_port` of an existing
        firewall rule. Require not `any` or empty protocol.
        """
        return pulumi.get(self, "source_port")

    @source_port.setter
    def source_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source_port", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This argument conflicts and is interchangeable
        with `project_id`. The owner of the firewall rule. Required if admin wants
        to create a firewall rule for another tenant. Changing this creates a new
        firewall rule.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.type_token("openstack:firewall/ruleV2:RuleV2")
class RuleV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_port: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 shared: Optional[pulumi.Input[_builtins.bool]] = None,
                 source_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 source_port: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a v2 firewall rule resource within OpenStack.

        > **Note:** Firewall v2 has no support for OVN currently.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        rule2 = openstack.firewall.RuleV2("rule_2",
            name="firewall_rule",
            description="drop TELNET traffic",
            action="deny",
            protocol="tcp",
            destination_port="23",
            enabled=True)
        ```

        ## Import

        Firewall Rules can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:firewall/ruleV2:RuleV2 rule_1 8dbc0c28-e49c-463f-b712-5c5d1bbac327
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: Action to be taken (must be "allow", "deny" or "reject")
               when the firewall rule matches. Changing this updates the `action` of an
               existing firewall rule. Default is `deny`.
        :param pulumi.Input[_builtins.str] description: A description for the firewall rule. Changing this
               updates the `description` of an existing firewall rule.
        :param pulumi.Input[_builtins.str] destination_ip_address: The destination IP address on which the
               firewall rule operates. Changing this updates the `destination_ip_address`
               of an existing firewall rule.
        :param pulumi.Input[_builtins.str] destination_port: The destination port on which the firewall
               rule operates. Changing this updates the `destination_port` of an existing
               firewall rule. Require not `any` or empty protocol.
        :param pulumi.Input[_builtins.bool] enabled: Enabled status for the firewall rule (must be "true"
               or "false" if provided - defaults to "true"). Changing this updates the
               `enabled` status of an existing firewall rule.
        :param pulumi.Input[_builtins.int] ip_version: IP version, either 4 or 6. Changing this
               updates the `ip_version` of an existing firewall rule. Default is `4`.
        :param pulumi.Input[_builtins.str] name: A unique name for the firewall rule. Changing this
               updates the `name` of an existing firewall rule.
        :param pulumi.Input[_builtins.str] project_id: This argument conflicts and is interchangeable
               with `tenant_id`. The owner of the firewall rule. Required if admin wants
               to create a firewall rule for another project. Changing this creates a new
               firewall rule.
        :param pulumi.Input[_builtins.str] protocol: (Optional; Required if `source_port` or `destination_port` is not
               empty) The protocol type on which the firewall rule operates.
               Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
               `protocol` of an existing firewall rule. Default is `any`.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the v2 networking client.
               A networking client is needed to create a firewall rule. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               firewall rule.
        :param pulumi.Input[_builtins.bool] shared: Sharing status of the firewall rule (must be "true"
               or "false" if provided). If this is "true" the policy is visible to, and
               can be used in, firewalls in other tenants. Changing this updates the
               `shared` status of an existing firewall policy. On
        :param pulumi.Input[_builtins.str] source_ip_address: The source IP address on which the firewall
               rule operates. Changing this updates the `source_ip_address` of an existing
               firewall rule.
        :param pulumi.Input[_builtins.str] source_port: The source port on which the firewall
               rule operates. Changing this updates the `source_port` of an existing
               firewall rule. Require not `any` or empty protocol.
        :param pulumi.Input[_builtins.str] tenant_id: This argument conflicts and is interchangeable
               with `project_id`. The owner of the firewall rule. Required if admin wants
               to create a firewall rule for another tenant. Changing this creates a new
               firewall rule.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[RuleV2Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a v2 firewall rule resource within OpenStack.

        > **Note:** Firewall v2 has no support for OVN currently.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        rule2 = openstack.firewall.RuleV2("rule_2",
            name="firewall_rule",
            description="drop TELNET traffic",
            action="deny",
            protocol="tcp",
            destination_port="23",
            enabled=True)
        ```

        ## Import

        Firewall Rules can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:firewall/ruleV2:RuleV2 rule_1 8dbc0c28-e49c-463f-b712-5c5d1bbac327
        ```


        :param str resource_name: The name of the resource.
        :param RuleV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 destination_port: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_version: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 shared: Optional[pulumi.Input[_builtins.bool]] = None,
                 source_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 source_port: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleV2Args.__new__(RuleV2Args)

            __props__.__dict__["action"] = action
            __props__.__dict__["description"] = description
            __props__.__dict__["destination_ip_address"] = destination_ip_address
            __props__.__dict__["destination_port"] = destination_port
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["ip_version"] = ip_version
            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["region"] = region
            __props__.__dict__["shared"] = shared
            __props__.__dict__["source_ip_address"] = source_ip_address
            __props__.__dict__["source_port"] = source_port
            __props__.__dict__["tenant_id"] = tenant_id
        super(RuleV2, __self__).__init__(
            'openstack:firewall/ruleV2:RuleV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            destination_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
            destination_port: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            ip_version: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            protocol: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            shared: Optional[pulumi.Input[_builtins.bool]] = None,
            source_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
            source_port: Optional[pulumi.Input[_builtins.str]] = None,
            tenant_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'RuleV2':
        """
        Get an existing RuleV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] action: Action to be taken (must be "allow", "deny" or "reject")
               when the firewall rule matches. Changing this updates the `action` of an
               existing firewall rule. Default is `deny`.
        :param pulumi.Input[_builtins.str] description: A description for the firewall rule. Changing this
               updates the `description` of an existing firewall rule.
        :param pulumi.Input[_builtins.str] destination_ip_address: The destination IP address on which the
               firewall rule operates. Changing this updates the `destination_ip_address`
               of an existing firewall rule.
        :param pulumi.Input[_builtins.str] destination_port: The destination port on which the firewall
               rule operates. Changing this updates the `destination_port` of an existing
               firewall rule. Require not `any` or empty protocol.
        :param pulumi.Input[_builtins.bool] enabled: Enabled status for the firewall rule (must be "true"
               or "false" if provided - defaults to "true"). Changing this updates the
               `enabled` status of an existing firewall rule.
        :param pulumi.Input[_builtins.int] ip_version: IP version, either 4 or 6. Changing this
               updates the `ip_version` of an existing firewall rule. Default is `4`.
        :param pulumi.Input[_builtins.str] name: A unique name for the firewall rule. Changing this
               updates the `name` of an existing firewall rule.
        :param pulumi.Input[_builtins.str] project_id: This argument conflicts and is interchangeable
               with `tenant_id`. The owner of the firewall rule. Required if admin wants
               to create a firewall rule for another project. Changing this creates a new
               firewall rule.
        :param pulumi.Input[_builtins.str] protocol: (Optional; Required if `source_port` or `destination_port` is not
               empty) The protocol type on which the firewall rule operates.
               Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
               `protocol` of an existing firewall rule. Default is `any`.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the v2 networking client.
               A networking client is needed to create a firewall rule. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               firewall rule.
        :param pulumi.Input[_builtins.bool] shared: Sharing status of the firewall rule (must be "true"
               or "false" if provided). If this is "true" the policy is visible to, and
               can be used in, firewalls in other tenants. Changing this updates the
               `shared` status of an existing firewall policy. On
        :param pulumi.Input[_builtins.str] source_ip_address: The source IP address on which the firewall
               rule operates. Changing this updates the `source_ip_address` of an existing
               firewall rule.
        :param pulumi.Input[_builtins.str] source_port: The source port on which the firewall
               rule operates. Changing this updates the `source_port` of an existing
               firewall rule. Require not `any` or empty protocol.
        :param pulumi.Input[_builtins.str] tenant_id: This argument conflicts and is interchangeable
               with `project_id`. The owner of the firewall rule. Required if admin wants
               to create a firewall rule for another tenant. Changing this creates a new
               firewall rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleV2State.__new__(_RuleV2State)

        __props__.__dict__["action"] = action
        __props__.__dict__["description"] = description
        __props__.__dict__["destination_ip_address"] = destination_ip_address
        __props__.__dict__["destination_port"] = destination_port
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["ip_version"] = ip_version
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["region"] = region
        __props__.__dict__["shared"] = shared
        __props__.__dict__["source_ip_address"] = source_ip_address
        __props__.__dict__["source_port"] = source_port
        __props__.__dict__["tenant_id"] = tenant_id
        return RuleV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Action to be taken (must be "allow", "deny" or "reject")
        when the firewall rule matches. Changing this updates the `action` of an
        existing firewall rule. Default is `deny`.
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A description for the firewall rule. Changing this
        updates the `description` of an existing firewall rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="destinationIpAddress")
    def destination_ip_address(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The destination IP address on which the
        firewall rule operates. Changing this updates the `destination_ip_address`
        of an existing firewall rule.
        """
        return pulumi.get(self, "destination_ip_address")

    @_builtins.property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The destination port on which the firewall
        rule operates. Changing this updates the `destination_port` of an existing
        firewall rule. Require not `any` or empty protocol.
        """
        return pulumi.get(self, "destination_port")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enabled status for the firewall rule (must be "true"
        or "false" if provided - defaults to "true"). Changing this updates the
        `enabled` status of an existing firewall rule.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="ipVersion")
    def ip_version(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        IP version, either 4 or 6. Changing this
        updates the `ip_version` of an existing firewall rule. Default is `4`.
        """
        return pulumi.get(self, "ip_version")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A unique name for the firewall rule. Changing this
        updates the `name` of an existing firewall rule.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        This argument conflicts and is interchangeable
        with `tenant_id`. The owner of the firewall rule. Required if admin wants
        to create a firewall rule for another project. Changing this creates a new
        firewall rule.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (Optional; Required if `source_port` or `destination_port` is not
        empty) The protocol type on which the firewall rule operates.
        Valid values are: `tcp`, `udp`, `icmp`, and `any`. Changing this updates the
        `protocol` of an existing firewall rule. Default is `any`.
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the v2 networking client.
        A networking client is needed to create a firewall rule. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        firewall rule.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def shared(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Sharing status of the firewall rule (must be "true"
        or "false" if provided). If this is "true" the policy is visible to, and
        can be used in, firewalls in other tenants. Changing this updates the
        `shared` status of an existing firewall policy. On
        """
        return pulumi.get(self, "shared")

    @_builtins.property
    @pulumi.getter(name="sourceIpAddress")
    def source_ip_address(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The source IP address on which the firewall
        rule operates. Changing this updates the `source_ip_address` of an existing
        firewall rule.
        """
        return pulumi.get(self, "source_ip_address")

    @_builtins.property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The source port on which the firewall
        rule operates. Changing this updates the `source_port` of an existing
        firewall rule. Require not `any` or empty protocol.
        """
        return pulumi.get(self, "source_port")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[_builtins.str]:
        """
        This argument conflicts and is interchangeable
        with `project_id`. The owner of the firewall rule. Required if admin wants
        to create a firewall rule for another tenant. Changing this creates a new
        firewall rule.
        """
        return pulumi.get(self, "tenant_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'PortAssociateV2RouteArgs',
    'PortAssociateV2RouteArgsDict',
]

class PortAssociateV2RouteArgsDict(TypedDict):
    type: pulumi.Input[_builtins.str]
    """
    Can be `prefix` or `bgpvpn`. For the `prefix` type, the
    CIDR prefix (v4 or v6) must be specified in the `prefix` key. For the
    `bgpvpn` type, the BGP VPN ID must be specified in the `bgpvpn_id` key.
    """
    bgpvpn_id: NotRequired[pulumi.Input[_builtins.str]]
    """
    The ID of the BGP VPN to be advertised. Required
    if `type` is `bgpvpn`. Conflicts with `prefix`.
    """
    local_pref: NotRequired[pulumi.Input[_builtins.int]]
    """
    The BGP LOCAL\\_PREF value of the routes that will
    be advertised.
    """
    prefix: NotRequired[pulumi.Input[_builtins.str]]
    """
    The CIDR prefix (v4 or v6) to be advertised. Required
    if `type` is `prefix`. Conflicts with `bgpvpn_id`.
    """

@pulumi.input_type
class PortAssociateV2RouteArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 bgpvpn_id: Optional[pulumi.Input[_builtins.str]] = None,
                 local_pref: Optional[pulumi.Input[_builtins.int]] = None,
                 prefix: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] type: Can be `prefix` or `bgpvpn`. For the `prefix` type, the
               CIDR prefix (v4 or v6) must be specified in the `prefix` key. For the
               `bgpvpn` type, the BGP VPN ID must be specified in the `bgpvpn_id` key.
        :param pulumi.Input[_builtins.str] bgpvpn_id: The ID of the BGP VPN to be advertised. Required
               if `type` is `bgpvpn`. Conflicts with `prefix`.
        :param pulumi.Input[_builtins.int] local_pref: The BGP LOCAL\\_PREF value of the routes that will
               be advertised.
        :param pulumi.Input[_builtins.str] prefix: The CIDR prefix (v4 or v6) to be advertised. Required
               if `type` is `prefix`. Conflicts with `bgpvpn_id`.
        """
        pulumi.set(__self__, "type", type)
        if bgpvpn_id is not None:
            pulumi.set(__self__, "bgpvpn_id", bgpvpn_id)
        if local_pref is not None:
            pulumi.set(__self__, "local_pref", local_pref)
        if prefix is not None:
            pulumi.set(__self__, "prefix", prefix)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Can be `prefix` or `bgpvpn`. For the `prefix` type, the
        CIDR prefix (v4 or v6) must be specified in the `prefix` key. For the
        `bgpvpn` type, the BGP VPN ID must be specified in the `bgpvpn_id` key.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="bgpvpnId")
    def bgpvpn_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the BGP VPN to be advertised. Required
        if `type` is `bgpvpn`. Conflicts with `prefix`.
        """
        return pulumi.get(self, "bgpvpn_id")

    @bgpvpn_id.setter
    def bgpvpn_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "bgpvpn_id", value)

    @_builtins.property
    @pulumi.getter(name="localPref")
    def local_pref(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The BGP LOCAL\\_PREF value of the routes that will
        be advertised.
        """
        return pulumi.get(self, "local_pref")

    @local_pref.setter
    def local_pref(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "local_pref", value)

    @_builtins.property
    @pulumi.getter
    def prefix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The CIDR prefix (v4 or v6) to be advertised. Required
        if `type` is `prefix`. Conflicts with `bgpvpn_id`.
        """
        return pulumi.get(self, "prefix")

    @prefix.setter
    def prefix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "prefix", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BgpPeerV2Args', 'BgpPeerV2']

@pulumi.input_type
class BgpPeerV2Args:
    def __init__(__self__, *,
                 peer_ip: pulumi.Input[_builtins.str],
                 remote_as: pulumi.Input[_builtins.int],
                 auth_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a BgpPeerV2 resource.

        :param pulumi.Input[_builtins.str] peer_ip: The IP address of the BGP peer. Must be a valid IP
               address. Changing this creates a new BGP peer.
        :param pulumi.Input[_builtins.int] remote_as: The AS number of the BGP peer. Changing this
               creates a new BGP peer.
        :param pulumi.Input[_builtins.str] auth_type: The authentication type to use. Can be one of `none`
               or `md5`. Defaults to `none`. If set to not `none`, the `password` argument
               must also be provided. Changing this creates a new BGP peer.
        :param pulumi.Input[_builtins.str] name: A name for the BGP peer.
        :param pulumi.Input[_builtins.str] password: The password used for MD5 authentication. Must be set
               only when `auth_type` is not `none`.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a Neutron network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new BGP
               peer.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant/project ID. Required if admin privileges
               are used. Changing this creates a new BGP peer.
        """
        pulumi.set(__self__, "peer_ip", peer_ip)
        pulumi.set(__self__, "remote_as", remote_as)
        if auth_type is not None:
            pulumi.set(__self__, "auth_type", auth_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter(name="peerIp")
    def peer_ip(self) -> pulumi.Input[_builtins.str]:
        """
        The IP address of the BGP peer. Must be a valid IP
        address. Changing this creates a new BGP peer.
        """
        return pulumi.get(self, "peer_ip")

    @peer_ip.setter
    def peer_ip(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "peer_ip", value)

    @_builtins.property
    @pulumi.getter(name="remoteAs")
    def remote_as(self) -> pulumi.Input[_builtins.int]:
        """
        The AS number of the BGP peer. Changing this
        creates a new BGP peer.
        """
        return pulumi.get(self, "remote_as")

    @remote_as.setter
    def remote_as(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "remote_as", value)

    @_builtins.property
    @pulumi.getter(name="authType")
    def auth_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The authentication type to use. Can be one of `none`
        or `md5`. Defaults to `none`. If set to not `none`, the `password` argument
        must also be provided. Changing this creates a new BGP peer.
        """
        return pulumi.get(self, "auth_type")

    @auth_type.setter
    def auth_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name for the BGP peer.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password used for MD5 authentication. Must be set
        only when `auth_type` is not `none`.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a Neutron network. If omitted, the
        `region` argument of the provider is used. Changing this creates a new BGP
        peer.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The tenant/project ID. Required if admin privileges
        are used. Changing this creates a new BGP peer.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.input_type
class _BgpPeerV2State:
    def __init__(__self__, *,
                 auth_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 peer_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_as: Optional[pulumi.Input[_builtins.int]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering BgpPeerV2 resources.

        :param pulumi.Input[_builtins.str] auth_type: The authentication type to use. Can be one of `none`
               or `md5`. Defaults to `none`. If set to not `none`, the `password` argument
               must also be provided. Changing this creates a new BGP peer.
        :param pulumi.Input[_builtins.str] name: A name for the BGP peer.
        :param pulumi.Input[_builtins.str] password: The password used for MD5 authentication. Must be set
               only when `auth_type` is not `none`.
        :param pulumi.Input[_builtins.str] peer_ip: The IP address of the BGP peer. Must be a valid IP
               address. Changing this creates a new BGP peer.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a Neutron network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new BGP
               peer.
        :param pulumi.Input[_builtins.int] remote_as: The AS number of the BGP peer. Changing this
               creates a new BGP peer.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant/project ID. Required if admin privileges
               are used. Changing this creates a new BGP peer.
        """
        if auth_type is not None:
            pulumi.set(__self__, "auth_type", auth_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if peer_ip is not None:
            pulumi.set(__self__, "peer_ip", peer_ip)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if remote_as is not None:
            pulumi.set(__self__, "remote_as", remote_as)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter(name="authType")
    def auth_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The authentication type to use. Can be one of `none`
        or `md5`. Defaults to `none`. If set to not `none`, the `password` argument
        must also be provided. Changing this creates a new BGP peer.
        """
        return pulumi.get(self, "auth_type")

    @auth_type.setter
    def auth_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name for the BGP peer.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The password used for MD5 authentication. Must be set
        only when `auth_type` is not `none`.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="peerIp")
    def peer_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP address of the BGP peer. Must be a valid IP
        address. Changing this creates a new BGP peer.
        """
        return pulumi.get(self, "peer_ip")

    @peer_ip.setter
    def peer_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "peer_ip", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a Neutron network. If omitted, the
        `region` argument of the provider is used. Changing this creates a new BGP
        peer.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="remoteAs")
    def remote_as(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The AS number of the BGP peer. Changing this
        creates a new BGP peer.
        """
        return pulumi.get(self, "remote_as")

    @remote_as.setter
    def remote_as(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "remote_as", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The tenant/project ID. Required if admin privileges
        are used. Changing this creates a new BGP peer.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)


@pulumi.type_token("openstack:networking/bgpPeerV2:BgpPeerV2")
class BgpPeerV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 peer_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_as: Optional[pulumi.Input[_builtins.int]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a V2 Neutron BGP Peer resource within OpenStack.

        This resource allows you to configure a BGP peer that can be associated with a
        BGP speaker to exchange routing information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        peer1 = openstack.networking.BgpPeerV2("peer_1",
            name="bgp_peer_1",
            peer_ip="192.0.2.10",
            remote_as=65001,
            auth_type="md5",
            password="supersecret")
        ```

        ## Import

        BGP peers can be imported using their ID:

        ```sh
        $ pulumi import openstack:networking/bgpPeerV2:BgpPeerV2 peer1 a1b2c3d4-e5f6-7890-abcd-1234567890ef
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_type: The authentication type to use. Can be one of `none`
               or `md5`. Defaults to `none`. If set to not `none`, the `password` argument
               must also be provided. Changing this creates a new BGP peer.
        :param pulumi.Input[_builtins.str] name: A name for the BGP peer.
        :param pulumi.Input[_builtins.str] password: The password used for MD5 authentication. Must be set
               only when `auth_type` is not `none`.
        :param pulumi.Input[_builtins.str] peer_ip: The IP address of the BGP peer. Must be a valid IP
               address. Changing this creates a new BGP peer.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a Neutron network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new BGP
               peer.
        :param pulumi.Input[_builtins.int] remote_as: The AS number of the BGP peer. Changing this
               creates a new BGP peer.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant/project ID. Required if admin privileges
               are used. Changing this creates a new BGP peer.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BgpPeerV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V2 Neutron BGP Peer resource within OpenStack.

        This resource allows you to configure a BGP peer that can be associated with a
        BGP speaker to exchange routing information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        peer1 = openstack.networking.BgpPeerV2("peer_1",
            name="bgp_peer_1",
            peer_ip="192.0.2.10",
            remote_as=65001,
            auth_type="md5",
            password="supersecret")
        ```

        ## Import

        BGP peers can be imported using their ID:

        ```sh
        $ pulumi import openstack:networking/bgpPeerV2:BgpPeerV2 peer1 a1b2c3d4-e5f6-7890-abcd-1234567890ef
        ```


        :param str resource_name: The name of the resource.
        :param BgpPeerV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BgpPeerV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 peer_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_as: Optional[pulumi.Input[_builtins.int]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BgpPeerV2Args.__new__(BgpPeerV2Args)

            __props__.__dict__["auth_type"] = auth_type
            __props__.__dict__["name"] = name
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            if peer_ip is None and not opts.urn:
                raise TypeError("Missing required property 'peer_ip'")
            __props__.__dict__["peer_ip"] = peer_ip
            __props__.__dict__["region"] = region
            if remote_as is None and not opts.urn:
                raise TypeError("Missing required property 'remote_as'")
            __props__.__dict__["remote_as"] = remote_as
            __props__.__dict__["tenant_id"] = tenant_id
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(BgpPeerV2, __self__).__init__(
            'openstack:networking/bgpPeerV2:BgpPeerV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_type: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            peer_ip: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            remote_as: Optional[pulumi.Input[_builtins.int]] = None,
            tenant_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'BgpPeerV2':
        """
        Get an existing BgpPeerV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_type: The authentication type to use. Can be one of `none`
               or `md5`. Defaults to `none`. If set to not `none`, the `password` argument
               must also be provided. Changing this creates a new BGP peer.
        :param pulumi.Input[_builtins.str] name: A name for the BGP peer.
        :param pulumi.Input[_builtins.str] password: The password used for MD5 authentication. Must be set
               only when `auth_type` is not `none`.
        :param pulumi.Input[_builtins.str] peer_ip: The IP address of the BGP peer. Must be a valid IP
               address. Changing this creates a new BGP peer.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create a Neutron network. If omitted, the
               `region` argument of the provider is used. Changing this creates a new BGP
               peer.
        :param pulumi.Input[_builtins.int] remote_as: The AS number of the BGP peer. Changing this
               creates a new BGP peer.
        :param pulumi.Input[_builtins.str] tenant_id: The tenant/project ID. Required if admin privileges
               are used. Changing this creates a new BGP peer.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BgpPeerV2State.__new__(_BgpPeerV2State)

        __props__.__dict__["auth_type"] = auth_type
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["peer_ip"] = peer_ip
        __props__.__dict__["region"] = region
        __props__.__dict__["remote_as"] = remote_as
        __props__.__dict__["tenant_id"] = tenant_id
        return BgpPeerV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="authType")
    def auth_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The authentication type to use. Can be one of `none`
        or `md5`. Defaults to `none`. If set to not `none`, the `password` argument
        must also be provided. Changing this creates a new BGP peer.
        """
        return pulumi.get(self, "auth_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A name for the BGP peer.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The password used for MD5 authentication. Must be set
        only when `auth_type` is not `none`.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter(name="peerIp")
    def peer_ip(self) -> pulumi.Output[_builtins.str]:
        """
        The IP address of the BGP peer. Must be a valid IP
        address. Changing this creates a new BGP peer.
        """
        return pulumi.get(self, "peer_ip")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create a Neutron network. If omitted, the
        `region` argument of the provider is used. Changing this creates a new BGP
        peer.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="remoteAs")
    def remote_as(self) -> pulumi.Output[_builtins.int]:
        """
        The AS number of the BGP peer. Changing this
        creates a new BGP peer.
        """
        return pulumi.get(self, "remote_as")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[_builtins.str]:
        """
        The tenant/project ID. Required if admin privileges
        are used. Changing this creates a new BGP peer.
        """
        return pulumi.get(self, "tenant_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['QuotaArgs', 'Quota']

@pulumi.input_type
class QuotaArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[_builtins.str],
                 health_monitor: Optional[pulumi.Input[_builtins.int]] = None,
                 l7_policy: Optional[pulumi.Input[_builtins.int]] = None,
                 l7_rule: Optional[pulumi.Input[_builtins.int]] = None,
                 listener: Optional[pulumi.Input[_builtins.int]] = None,
                 loadbalancer: Optional[pulumi.Input[_builtins.int]] = None,
                 member: Optional[pulumi.Input[_builtins.int]] = None,
                 pool: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Quota resource.

        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas. Changing this
               creates a new quota.
        :param pulumi.Input[_builtins.int] health_monitor: Quota value for health_monitors. Changing
               this updates the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] l7_policy: Quota value for l7_policies. Changing this
               updates the existing quota. Omitting it sets it to 0. Available in
               **Octavia minor version 2.19**.
        :param pulumi.Input[_builtins.int] l7_rule: Quota value for l7_rules. Changing this
               updates the existing quota. Omitting it sets it to 0. Available in
               **Octavia minor version 2.19**.
        :param pulumi.Input[_builtins.int] listener: Quota value for listeners. Changing this updates
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] loadbalancer: Quota value for loadbalancers. Changing this
               updates the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] member: Quota value for members. Changing this updates
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] pool: Quota value for pools. Changing this updates the
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.str] region: Region in which to manage quotas. Changing this
               creates a new quota. If ommited, the region of the credentials is used.
        """
        pulumi.set(__self__, "project_id", project_id)
        if health_monitor is not None:
            pulumi.set(__self__, "health_monitor", health_monitor)
        if l7_policy is not None:
            pulumi.set(__self__, "l7_policy", l7_policy)
        if l7_rule is not None:
            pulumi.set(__self__, "l7_rule", l7_rule)
        if listener is not None:
            pulumi.set(__self__, "listener", listener)
        if loadbalancer is not None:
            pulumi.set(__self__, "loadbalancer", loadbalancer)
        if member is not None:
            pulumi.set(__self__, "member", member)
        if pool is not None:
            pulumi.set(__self__, "pool", pool)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the project to manage quotas. Changing this
        creates a new quota.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="healthMonitor")
    def health_monitor(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for health_monitors. Changing
        this updates the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "health_monitor")

    @health_monitor.setter
    def health_monitor(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "health_monitor", value)

    @_builtins.property
    @pulumi.getter(name="l7Policy")
    def l7_policy(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for l7_policies. Changing this
        updates the existing quota. Omitting it sets it to 0. Available in
        **Octavia minor version 2.19**.
        """
        return pulumi.get(self, "l7_policy")

    @l7_policy.setter
    def l7_policy(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "l7_policy", value)

    @_builtins.property
    @pulumi.getter(name="l7Rule")
    def l7_rule(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for l7_rules. Changing this
        updates the existing quota. Omitting it sets it to 0. Available in
        **Octavia minor version 2.19**.
        """
        return pulumi.get(self, "l7_rule")

    @l7_rule.setter
    def l7_rule(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "l7_rule", value)

    @_builtins.property
    @pulumi.getter
    def listener(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for listeners. Changing this updates
        the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "listener")

    @listener.setter
    def listener(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "listener", value)

    @_builtins.property
    @pulumi.getter
    def loadbalancer(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for loadbalancers. Changing this
        updates the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "loadbalancer")

    @loadbalancer.setter
    def loadbalancer(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "loadbalancer", value)

    @_builtins.property
    @pulumi.getter
    def member(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for members. Changing this updates
        the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "member")

    @member.setter
    def member(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "member", value)

    @_builtins.property
    @pulumi.getter
    def pool(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for pools. Changing this updates the
        the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "pool")

    @pool.setter
    def pool(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "pool", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region in which to manage quotas. Changing this
        creates a new quota. If ommited, the region of the credentials is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _QuotaState:
    def __init__(__self__, *,
                 health_monitor: Optional[pulumi.Input[_builtins.int]] = None,
                 l7_policy: Optional[pulumi.Input[_builtins.int]] = None,
                 l7_rule: Optional[pulumi.Input[_builtins.int]] = None,
                 listener: Optional[pulumi.Input[_builtins.int]] = None,
                 loadbalancer: Optional[pulumi.Input[_builtins.int]] = None,
                 member: Optional[pulumi.Input[_builtins.int]] = None,
                 pool: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Quota resources.

        :param pulumi.Input[_builtins.int] health_monitor: Quota value for health_monitors. Changing
               this updates the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] l7_policy: Quota value for l7_policies. Changing this
               updates the existing quota. Omitting it sets it to 0. Available in
               **Octavia minor version 2.19**.
        :param pulumi.Input[_builtins.int] l7_rule: Quota value for l7_rules. Changing this
               updates the existing quota. Omitting it sets it to 0. Available in
               **Octavia minor version 2.19**.
        :param pulumi.Input[_builtins.int] listener: Quota value for listeners. Changing this updates
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] loadbalancer: Quota value for loadbalancers. Changing this
               updates the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] member: Quota value for members. Changing this updates
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] pool: Quota value for pools. Changing this updates the
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas. Changing this
               creates a new quota.
        :param pulumi.Input[_builtins.str] region: Region in which to manage quotas. Changing this
               creates a new quota. If ommited, the region of the credentials is used.
        """
        if health_monitor is not None:
            pulumi.set(__self__, "health_monitor", health_monitor)
        if l7_policy is not None:
            pulumi.set(__self__, "l7_policy", l7_policy)
        if l7_rule is not None:
            pulumi.set(__self__, "l7_rule", l7_rule)
        if listener is not None:
            pulumi.set(__self__, "listener", listener)
        if loadbalancer is not None:
            pulumi.set(__self__, "loadbalancer", loadbalancer)
        if member is not None:
            pulumi.set(__self__, "member", member)
        if pool is not None:
            pulumi.set(__self__, "pool", pool)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="healthMonitor")
    def health_monitor(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for health_monitors. Changing
        this updates the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "health_monitor")

    @health_monitor.setter
    def health_monitor(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "health_monitor", value)

    @_builtins.property
    @pulumi.getter(name="l7Policy")
    def l7_policy(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for l7_policies. Changing this
        updates the existing quota. Omitting it sets it to 0. Available in
        **Octavia minor version 2.19**.
        """
        return pulumi.get(self, "l7_policy")

    @l7_policy.setter
    def l7_policy(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "l7_policy", value)

    @_builtins.property
    @pulumi.getter(name="l7Rule")
    def l7_rule(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for l7_rules. Changing this
        updates the existing quota. Omitting it sets it to 0. Available in
        **Octavia minor version 2.19**.
        """
        return pulumi.get(self, "l7_rule")

    @l7_rule.setter
    def l7_rule(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "l7_rule", value)

    @_builtins.property
    @pulumi.getter
    def listener(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for listeners. Changing this updates
        the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "listener")

    @listener.setter
    def listener(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "listener", value)

    @_builtins.property
    @pulumi.getter
    def loadbalancer(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for loadbalancers. Changing this
        updates the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "loadbalancer")

    @loadbalancer.setter
    def loadbalancer(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "loadbalancer", value)

    @_builtins.property
    @pulumi.getter
    def member(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for members. Changing this updates
        the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "member")

    @member.setter
    def member(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "member", value)

    @_builtins.property
    @pulumi.getter
    def pool(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Quota value for pools. Changing this updates the
        the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "pool")

    @pool.setter
    def pool(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "pool", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the project to manage quotas. Changing this
        creates a new quota.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region in which to manage quotas. Changing this
        creates a new quota. If ommited, the region of the credentials is used.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.type_token("openstack:loadbalancer/quota:Quota")
class Quota(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 health_monitor: Optional[pulumi.Input[_builtins.int]] = None,
                 l7_policy: Optional[pulumi.Input[_builtins.int]] = None,
                 l7_rule: Optional[pulumi.Input[_builtins.int]] = None,
                 listener: Optional[pulumi.Input[_builtins.int]] = None,
                 loadbalancer: Optional[pulumi.Input[_builtins.int]] = None,
                 member: Optional[pulumi.Input[_builtins.int]] = None,
                 pool: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a V2 load balancer quota resource within OpenStack.

        > **Note:** This usually requires admin privileges.

        > **Note:** This resource has a no-op deletion so no actual actions will be done against the OpenStack
           API in case of delete call.

        > **Note:** This resource has attributes that depend on octavia minor versions.
        Please ensure your Openstack cloud supports the required minor version.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        project1 = openstack.identity.Project("project_1", name="project_1")
        quota1 = openstack.loadbalancer.Quota("quota_1",
            project_id=project1.id,
            loadbalancer=6,
            listener=7,
            member=8,
            pool=9,
            health_monitor=10,
            l7_policy=11,
            l7_rule=12)
        ```

        ## Import

        Quotas can be imported using the `project_id/region_name`, where region_name is the
        one defined is the Openstack credentials that are in use. E.g.

        ```sh
        $ pulumi import openstack:loadbalancer/quota:Quota quota_1 2a0f2240-c5e6-41de-896d-e80d97428d6b/region_1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] health_monitor: Quota value for health_monitors. Changing
               this updates the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] l7_policy: Quota value for l7_policies. Changing this
               updates the existing quota. Omitting it sets it to 0. Available in
               **Octavia minor version 2.19**.
        :param pulumi.Input[_builtins.int] l7_rule: Quota value for l7_rules. Changing this
               updates the existing quota. Omitting it sets it to 0. Available in
               **Octavia minor version 2.19**.
        :param pulumi.Input[_builtins.int] listener: Quota value for listeners. Changing this updates
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] loadbalancer: Quota value for loadbalancers. Changing this
               updates the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] member: Quota value for members. Changing this updates
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] pool: Quota value for pools. Changing this updates the
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas. Changing this
               creates a new quota.
        :param pulumi.Input[_builtins.str] region: Region in which to manage quotas. Changing this
               creates a new quota. If ommited, the region of the credentials is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QuotaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V2 load balancer quota resource within OpenStack.

        > **Note:** This usually requires admin privileges.

        > **Note:** This resource has a no-op deletion so no actual actions will be done against the OpenStack
           API in case of delete call.

        > **Note:** This resource has attributes that depend on octavia minor versions.
        Please ensure your Openstack cloud supports the required minor version.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        project1 = openstack.identity.Project("project_1", name="project_1")
        quota1 = openstack.loadbalancer.Quota("quota_1",
            project_id=project1.id,
            loadbalancer=6,
            listener=7,
            member=8,
            pool=9,
            health_monitor=10,
            l7_policy=11,
            l7_rule=12)
        ```

        ## Import

        Quotas can be imported using the `project_id/region_name`, where region_name is the
        one defined is the Openstack credentials that are in use. E.g.

        ```sh
        $ pulumi import openstack:loadbalancer/quota:Quota quota_1 2a0f2240-c5e6-41de-896d-e80d97428d6b/region_1
        ```


        :param str resource_name: The name of the resource.
        :param QuotaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QuotaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 health_monitor: Optional[pulumi.Input[_builtins.int]] = None,
                 l7_policy: Optional[pulumi.Input[_builtins.int]] = None,
                 l7_rule: Optional[pulumi.Input[_builtins.int]] = None,
                 listener: Optional[pulumi.Input[_builtins.int]] = None,
                 loadbalancer: Optional[pulumi.Input[_builtins.int]] = None,
                 member: Optional[pulumi.Input[_builtins.int]] = None,
                 pool: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QuotaArgs.__new__(QuotaArgs)

            __props__.__dict__["health_monitor"] = health_monitor
            __props__.__dict__["l7_policy"] = l7_policy
            __props__.__dict__["l7_rule"] = l7_rule
            __props__.__dict__["listener"] = listener
            __props__.__dict__["loadbalancer"] = loadbalancer
            __props__.__dict__["member"] = member
            __props__.__dict__["pool"] = pool
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
        super(Quota, __self__).__init__(
            'openstack:loadbalancer/quota:Quota',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            health_monitor: Optional[pulumi.Input[_builtins.int]] = None,
            l7_policy: Optional[pulumi.Input[_builtins.int]] = None,
            l7_rule: Optional[pulumi.Input[_builtins.int]] = None,
            listener: Optional[pulumi.Input[_builtins.int]] = None,
            loadbalancer: Optional[pulumi.Input[_builtins.int]] = None,
            member: Optional[pulumi.Input[_builtins.int]] = None,
            pool: Optional[pulumi.Input[_builtins.int]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'Quota':
        """
        Get an existing Quota resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] health_monitor: Quota value for health_monitors. Changing
               this updates the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] l7_policy: Quota value for l7_policies. Changing this
               updates the existing quota. Omitting it sets it to 0. Available in
               **Octavia minor version 2.19**.
        :param pulumi.Input[_builtins.int] l7_rule: Quota value for l7_rules. Changing this
               updates the existing quota. Omitting it sets it to 0. Available in
               **Octavia minor version 2.19**.
        :param pulumi.Input[_builtins.int] listener: Quota value for listeners. Changing this updates
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] loadbalancer: Quota value for loadbalancers. Changing this
               updates the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] member: Quota value for members. Changing this updates
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.int] pool: Quota value for pools. Changing this updates the
               the existing quota. Omitting it sets it to 0.
        :param pulumi.Input[_builtins.str] project_id: ID of the project to manage quotas. Changing this
               creates a new quota.
        :param pulumi.Input[_builtins.str] region: Region in which to manage quotas. Changing this
               creates a new quota. If ommited, the region of the credentials is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QuotaState.__new__(_QuotaState)

        __props__.__dict__["health_monitor"] = health_monitor
        __props__.__dict__["l7_policy"] = l7_policy
        __props__.__dict__["l7_rule"] = l7_rule
        __props__.__dict__["listener"] = listener
        __props__.__dict__["loadbalancer"] = loadbalancer
        __props__.__dict__["member"] = member
        __props__.__dict__["pool"] = pool
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        return Quota(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="healthMonitor")
    def health_monitor(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for health_monitors. Changing
        this updates the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "health_monitor")

    @_builtins.property
    @pulumi.getter(name="l7Policy")
    def l7_policy(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for l7_policies. Changing this
        updates the existing quota. Omitting it sets it to 0. Available in
        **Octavia minor version 2.19**.
        """
        return pulumi.get(self, "l7_policy")

    @_builtins.property
    @pulumi.getter(name="l7Rule")
    def l7_rule(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for l7_rules. Changing this
        updates the existing quota. Omitting it sets it to 0. Available in
        **Octavia minor version 2.19**.
        """
        return pulumi.get(self, "l7_rule")

    @_builtins.property
    @pulumi.getter
    def listener(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for listeners. Changing this updates
        the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "listener")

    @_builtins.property
    @pulumi.getter
    def loadbalancer(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for loadbalancers. Changing this
        updates the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "loadbalancer")

    @_builtins.property
    @pulumi.getter
    def member(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for members. Changing this updates
        the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "member")

    @_builtins.property
    @pulumi.getter
    def pool(self) -> pulumi.Output[_builtins.int]:
        """
        Quota value for pools. Changing this updates the
        the existing quota. Omitting it sets it to 0.
        """
        return pulumi.get(self, "pool")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the project to manage quotas. Changing this
        creates a new quota.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        Region in which to manage quotas. Changing this
        creates a new quota. If ommited, the region of the credentials is used.
        """
        return pulumi.get(self, "region")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AccountV1Args', 'AccountV1']

@pulumi.input_type
class AccountV1Args:
    def __init__(__self__, *,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AccountV1 resource.

        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] metadata: A map of custom key/value pairs to associate with the
               account metadata. Changing the `Quota-Bytes` key value is allowed to be
               updated only by the cloud administrator.
        :param pulumi.Input[_builtins.str] project_id: The project ID of the corresponding account. If
               omitted, the token's project ID is used. Changing this creates a new account.
        :param pulumi.Input[_builtins.str] region: The region in which to create the account. If omitted,
               the `region` argument of the provider is used. Changing this creates a new
               account.
        """
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map of custom key/value pairs to associate with the
        account metadata. Changing the `Quota-Bytes` key value is allowed to be
        updated only by the cloud administrator.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "metadata", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project ID of the corresponding account. If
        omitted, the token's project ID is used. Changing this creates a new account.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the account. If omitted,
        the `region` argument of the provider is used. Changing this creates a new
        account.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _AccountV1State:
    def __init__(__self__, *,
                 bytes_used: Optional[pulumi.Input[_builtins.int]] = None,
                 container_count: Optional[pulumi.Input[_builtins.int]] = None,
                 headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 object_count: Optional[pulumi.Input[_builtins.int]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 quota_bytes: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AccountV1 resources.

        :param pulumi.Input[_builtins.int] bytes_used: The number of bytes used by the account.
        :param pulumi.Input[_builtins.int] container_count: The number of containers in the account.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] headers: A map of headers returned for the account.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] metadata: A map of custom key/value pairs to associate with the
               account metadata. Changing the `Quota-Bytes` key value is allowed to be
               updated only by the cloud administrator.
        :param pulumi.Input[_builtins.int] object_count: The number of objects in the account.
        :param pulumi.Input[_builtins.str] project_id: The project ID of the corresponding account. If
               omitted, the token's project ID is used. Changing this creates a new account.
        :param pulumi.Input[_builtins.int] quota_bytes: The number of bytes allowed for the account.
        :param pulumi.Input[_builtins.str] region: The region in which to create the account. If omitted,
               the `region` argument of the provider is used. Changing this creates a new
               account.
        """
        if bytes_used is not None:
            pulumi.set(__self__, "bytes_used", bytes_used)
        if container_count is not None:
            pulumi.set(__self__, "container_count", container_count)
        if headers is not None:
            pulumi.set(__self__, "headers", headers)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if object_count is not None:
            pulumi.set(__self__, "object_count", object_count)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if quota_bytes is not None:
            pulumi.set(__self__, "quota_bytes", quota_bytes)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="bytesUsed")
    def bytes_used(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of bytes used by the account.
        """
        return pulumi.get(self, "bytes_used")

    @bytes_used.setter
    def bytes_used(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "bytes_used", value)

    @_builtins.property
    @pulumi.getter(name="containerCount")
    def container_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of containers in the account.
        """
        return pulumi.get(self, "container_count")

    @container_count.setter
    def container_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "container_count", value)

    @_builtins.property
    @pulumi.getter
    def headers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map of headers returned for the account.
        """
        return pulumi.get(self, "headers")

    @headers.setter
    def headers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "headers", value)

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A map of custom key/value pairs to associate with the
        account metadata. Changing the `Quota-Bytes` key value is allowed to be
        updated only by the cloud administrator.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "metadata", value)

    @_builtins.property
    @pulumi.getter(name="objectCount")
    def object_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of objects in the account.
        """
        return pulumi.get(self, "object_count")

    @object_count.setter
    def object_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "object_count", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project ID of the corresponding account. If
        omitted, the token's project ID is used. Changing this creates a new account.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="quotaBytes")
    def quota_bytes(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of bytes allowed for the account.
        """
        return pulumi.get(self, "quota_bytes")

    @quota_bytes.setter
    def quota_bytes(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "quota_bytes", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the account. If omitted,
        the `region` argument of the provider is used. Changing this creates a new
        account.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.type_token("openstack:objectstorage/accountV1:AccountV1")
class AccountV1(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a V1 account resource within OpenStack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        account1 = openstack.objectstorage.AccountV1("account_1",
            region="RegionOne",
            metadata={
                "Temp-Url-Key": "testkey",
                "test": "true",
            })
        ```

        ## Import

        This resource can be imported by specifying the project ID of the account:

        ```sh
        $ pulumi import openstack:objectstorage/accountV1:AccountV1 account_1 1202b3d0aaa44cfc8b79475c007b0711
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] metadata: A map of custom key/value pairs to associate with the
               account metadata. Changing the `Quota-Bytes` key value is allowed to be
               updated only by the cloud administrator.
        :param pulumi.Input[_builtins.str] project_id: The project ID of the corresponding account. If
               omitted, the token's project ID is used. Changing this creates a new account.
        :param pulumi.Input[_builtins.str] region: The region in which to create the account. If omitted,
               the `region` argument of the provider is used. Changing this creates a new
               account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AccountV1Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V1 account resource within OpenStack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        account1 = openstack.objectstorage.AccountV1("account_1",
            region="RegionOne",
            metadata={
                "Temp-Url-Key": "testkey",
                "test": "true",
            })
        ```

        ## Import

        This resource can be imported by specifying the project ID of the account:

        ```sh
        $ pulumi import openstack:objectstorage/accountV1:AccountV1 account_1 1202b3d0aaa44cfc8b79475c007b0711
        ```


        :param str resource_name: The name of the resource.
        :param AccountV1Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountV1Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountV1Args.__new__(AccountV1Args)

            __props__.__dict__["metadata"] = metadata
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["bytes_used"] = None
            __props__.__dict__["container_count"] = None
            __props__.__dict__["headers"] = None
            __props__.__dict__["object_count"] = None
            __props__.__dict__["quota_bytes"] = None
        super(AccountV1, __self__).__init__(
            'openstack:objectstorage/accountV1:AccountV1',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bytes_used: Optional[pulumi.Input[_builtins.int]] = None,
            container_count: Optional[pulumi.Input[_builtins.int]] = None,
            headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            object_count: Optional[pulumi.Input[_builtins.int]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            quota_bytes: Optional[pulumi.Input[_builtins.int]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'AccountV1':
        """
        Get an existing AccountV1 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] bytes_used: The number of bytes used by the account.
        :param pulumi.Input[_builtins.int] container_count: The number of containers in the account.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] headers: A map of headers returned for the account.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] metadata: A map of custom key/value pairs to associate with the
               account metadata. Changing the `Quota-Bytes` key value is allowed to be
               updated only by the cloud administrator.
        :param pulumi.Input[_builtins.int] object_count: The number of objects in the account.
        :param pulumi.Input[_builtins.str] project_id: The project ID of the corresponding account. If
               omitted, the token's project ID is used. Changing this creates a new account.
        :param pulumi.Input[_builtins.int] quota_bytes: The number of bytes allowed for the account.
        :param pulumi.Input[_builtins.str] region: The region in which to create the account. If omitted,
               the `region` argument of the provider is used. Changing this creates a new
               account.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountV1State.__new__(_AccountV1State)

        __props__.__dict__["bytes_used"] = bytes_used
        __props__.__dict__["container_count"] = container_count
        __props__.__dict__["headers"] = headers
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["object_count"] = object_count
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["quota_bytes"] = quota_bytes
        __props__.__dict__["region"] = region
        return AccountV1(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="bytesUsed")
    def bytes_used(self) -> pulumi.Output[_builtins.int]:
        """
        The number of bytes used by the account.
        """
        return pulumi.get(self, "bytes_used")

    @_builtins.property
    @pulumi.getter(name="containerCount")
    def container_count(self) -> pulumi.Output[_builtins.int]:
        """
        The number of containers in the account.
        """
        return pulumi.get(self, "container_count")

    @_builtins.property
    @pulumi.getter
    def headers(self) -> pulumi.Output[Mapping[str, _builtins.str]]:
        """
        A map of headers returned for the account.
        """
        return pulumi.get(self, "headers")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A map of custom key/value pairs to associate with the
        account metadata. Changing the `Quota-Bytes` key value is allowed to be
        updated only by the cloud administrator.
        """
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter(name="objectCount")
    def object_count(self) -> pulumi.Output[_builtins.int]:
        """
        The number of objects in the account.
        """
        return pulumi.get(self, "object_count")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The project ID of the corresponding account. If
        omitted, the token's project ID is used. Changing this creates a new account.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="quotaBytes")
    def quota_bytes(self) -> pulumi.Output[_builtins.int]:
        """
        The number of bytes allowed for the account.
        """
        return pulumi.get(self, "quota_bytes")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to create the account. If omitted,
        the `region` argument of the provider is used. Changing this creates a new
        account.
        """
        return pulumi.get(self, "region")

